;+
;Procedure: WI_LOAD_MFI
;
;Purpose:  Loads THEMIS fluxgate magnetometer data
;
;keywords:
;   TRANGE= (Optional) Time range of interest  (2 element array).
;   /VERBOSE : set to output some useful info
;Example:
;   thg_load_fgm,/all
;Notes:
;  This routine is (should be) platform independent.
;
;
; $LastChangedBy: davin-win $
; $LastChangedDate: 2007-06-08 06:46:50 -0700 (Fri, 08 Jun 2007) $
; $LastChangedRevision: 766 $
; $URL $
;-
pro wi_load_mfi,type,all=all,files=files,trange=trange,verbose=verbose,downloadonly=downloadonly, $
      cdf_data=cdf_data,get_support_data=get_support_data,varformat=varformat,datatype=datatype, $
      addmaster=addmaster

    wind_init

   if keyword_set(verbose) then source.verbose >= verbose


;    res = 3600l*24     ; one day resolution in the files
;    tr = timerange(trange)
;    n = ceil((tr[1]-tr[0])/res)  > 1
;    times = dindgen(n)*res + tr[0]

   if not keyword_set(datatype) then datatype = 'h0'

source = !wind
if 0 then begin
   case datatype of
   'k0':     format = 'wind/mfi/k0/YYYY/wi_k0_mfi_YYYYMMDD_v0?.cdf'
   'h0':     format = 'wind/mfi/h0/YYYY/wi_h0_mfi_YYYYMMDD_v03.cdf'
   endcase
endif else begin
   case datatype of
   'k0':     format = 'istp/wind/mfi/YYYY/wi_k0_mfi_YYYYMMDD_v0?.cdf'
   'h0':     format = 'istp/wind/mfi_h0/YYYY/wi_h0_mfi_YYYYMMDD_v03.cdf'
   endcase
endelse

;   source.remote_data_dir = 'ftp://cdaweb.gsfc.nasa.gov/pub/'
;   source.remote_data_dir ='http://themis.ssl.berkeley.edu/data/

   relpathnames = file_dailynames(file_format=format,trange=trange,addmaster=addmaster)

   files = file_retrieve(relpathnames, _extra=source)

   if keyword_set(downloadonly) then return

   cdf2tplot,file=files,all=all,varformat=varformat,verbose=verbose,prefix='wi_mfi_'     ; load data into tplot variables

end
